@@ -1,48 +1,103 @@
 package Email::Sender::Failure;
 {
-  $Email::Sender::Failure::VERSION = '0.110005';
+  $Email::Sender::Failure::VERSION = '1.300010';
 }
-use Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw(ArrayRef);
+use Carp ();
 extends 'Throwable::Error';
 # ABSTRACT: a report of failure from an email sending transport
 
 
+
+
+
+
+
+
+
+
+
+
+
 has code => (
   is => 'ro',
 );
 
 
-has _recipients => (
-  is         => 'rw',
-  isa        => 'ArrayRef',
-  auto_deref => 1,
-  init_arg   => 'recipients',
+
+
+
+
+
+has recipients => (
+  isa     => ArrayRef,
+  default => sub {  []  },
+  writer  => '_set_recipients',
+  reader  => '__get_recipients',
+  is      => 'rw',
+  accessor => undef,
 );
 
-sub recipients { shift->_recipients }
+sub __recipients { @{$_[0]->__get_recipients} }
+
+sub recipients {
+  my ($self) = @_;
+  return $self->__recipients if wantarray;
+  return if ! defined wantarray;
+
+  Carp::carp("recipients in scalar context is deprecated and WILL BE REMOVED");
+  return $self->__get_recipients;
+}
+
+
+
+
+
+
+
+
+
+
+
 
 
 sub BUILD {
   my ($self) = @_;
-  confess("message must contain non-space characters")
+  Carp::confess("message must contain non-space characters")
     unless $self->message =~ /\S/;
 }
 
 
-__PACKAGE__->meta->make_immutable(inline_constructor => 0);
-no Moose;
+
+
+
+
+
+
+
+
+
+
+
+
+
+no Moo;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Failure - a report of failure from an email sending transport
 
 =head1 VERSION
 
-version 0.110005
+version 1.300010
 
 =head1 ATTRIBUTES
 
@@ -58,8 +113,7 @@ for network protocol transports like SMTP.  This may be undefined.
 
 =head2 recipients
 
-This returns a list (or, in scalar context, an arrayref) of addresses to which
-the email could not be sent.
+This returns a list of addresses to which the email could not be sent.
 
 =head1 METHODS
 
@@ -91,10 +145,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
