@@ -1,18 +1,38 @@
 package Email::Sender::Role::CommonSending;
 {
-  $Email::Sender::Role::CommonSending::VERSION = '0.110005';
+  $Email::Sender::Role::CommonSending::VERSION = '1.300010';
 }
-use Moose::Role;
+use Moo::Role;
 # ABSTRACT: the common sending tasks most Email::Sender classes will need
 
-use Carp;
-use Email::Abstract;
+use Carp ();
+use Email::Abstract 3.006;
 use Email::Sender::Success;
 use Email::Sender::Failure::Temporary;
 use Email::Sender::Failure::Permanent;
 use Scalar::Util ();
 use Try::Tiny;
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 with 'Email::Sender';
 
@@ -26,10 +46,13 @@ sub send {
   try {
     return $self->send_email($email, $envelope, @rest);
   } catch {
-    confess('unknown error') unless my $err = $_;
+    Carp::confess('unknown error') unless my $err = $_;
 
-    if (try { $err->isa('Email::Sender::Failure') } and ! $err->recipients) {
-      $err->_recipients([ @{ $envelope->{to} } ]);
+    if (
+      try { $err->isa('Email::Sender::Failure') }
+      and ! (my @tmp = $err->recipients)
+    ) {
+      $err->_set_recipients([ @{ $envelope->{to} } ]);
     }
 
     die $err;
@@ -37,21 +60,34 @@ sub send {
 }
 
 
+
+
+
+
+
+
 sub prepare_email {
   my ($self, $msg) = @_;
 
-  confess("no email passed in to sender") unless defined $msg;
+  Carp::confess("no email passed in to sender") unless defined $msg;
 
   # We check blessed because if someone would pass in a large message, in some
   # perls calling isa on the string would create a package with the string as
   # the name.  If the message was (say) two megs, now you'd have a two meg hash
   # key in the stash.  Oops! -- rjbs, 2008-12-04
-  return $msg if blessed $msg and eval { $msg->isa('Email::Abstract') };
+  return $msg if Scalar::Util::blessed($msg) and eval { $msg->isa('Email::Abstract') };
 
   return Email::Abstract->new($msg);
 }
 
 
+
+
+
+
+
+
+
 sub prepare_envelope {
   my ($self, $env) = @_;
 
@@ -63,24 +99,37 @@ sub prepare_envelope {
 }
 
 
+
+
+
+
+
+
+
+
+
+
 sub success {
   my $self = shift;
   my $success = Email::Sender::Success->new(@_);
 }
 
-no Moose::Role;
+no Moo::Role;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Role::CommonSending - the common sending tasks most Email::Sender classes will need
 
 =head1 VERSION
 
-version 0.110005
+version 1.300010
 
 =head1 DESCRIPTION
 
@@ -129,10 +178,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
