@@ -1,29 +1,37 @@
 package Email::Sender::Role::HasMessage;
 {
-  $Email::Sender::Role::HasMessage::VERSION = '0.110005';
+  $Email::Sender::Role::HasMessage::VERSION = '1.300010';
 }
-use Moose::Role;
+use Moo::Role;
 # ABSTRACT: an object that has a message
 
 
+
+
+
+
+
 has message => (
   is       => 'ro',
   required => 1,
 );
 
-no Moose::Role;
+no Moo::Role;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Role::HasMessage - an object that has a message
 
 =head1 VERSION
 
-version 0.110005
+version 1.300010
 
 =head1 ATTRIBUTES
 
@@ -37,10 +45,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
