@@ -1,25 +1,33 @@
 package Email::Sender::Success;
 {
-  $Email::Sender::Success::VERSION = '0.110005';
+  $Email::Sender::Success::VERSION = '1.300010';
 }
-use Moose;
+use Moo;
 # ABSTRACT: the result of successfully sending mail
 
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
+
+
+
+
+
+
+no Moo;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Success - the result of successfully sending mail
 
 =head1 VERSION
 
-version 0.110005
+version 1.300010
 
 =head1 DESCRIPTION
 
@@ -32,10 +40,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
