@@ -1,28 +1,36 @@
 package Email::Sender::Transport::DevNull;
 {
-  $Email::Sender::Transport::DevNull::VERSION = '0.110005';
+  $Email::Sender::Transport::DevNull::VERSION = '1.300010';
 }
-use Moose;
+use Moo;
 with 'Email::Sender::Transport';
 # ABSTRACT: happily throw away your mail
 
 
+
+
+
+
+
+
 sub send_email { return $_[0]->success }
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Transport::DevNull - happily throw away your mail
 
 =head1 VERSION
 
-version 0.110005
+version 1.300010
 
 =head1 DESCRIPTION
 
@@ -35,10 +43,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
