@@ -1,24 +1,39 @@
 package Email::Sender::Transport::Failable;
 {
-  $Email::Sender::Transport::Failable::VERSION = '0.110005';
+  $Email::Sender::Transport::Failable::VERSION = '1.300010';
 }
-use Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw(ArrayRef);
 extends 'Email::Sender::Transport::Wrapper';
 # ABSTRACT: a wrapper to makes things fail predictably
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 has 'failure_conditions' => (
-  is  => 'ro',
-  isa => 'ArrayRef',
-  clearer    => 'clear_failure_conditions',
-  auto_deref => 1,
-  default    => sub { [] },
+  isa => ArrayRef,
+  default => sub { [] },
+  is      => 'ro',
+  reader  => '_failure_conditions',
 );
 
-sub fail_if {
-  my ($self, $cond) = @_;
-  push @{ scalar $self->failure_conditions }, $cond;
-}
+sub failure_conditions { @{$_[0]->_failure_conditions} }
+sub fail_if { push @{shift->_failure_conditions}, @_ }
+sub clear_failure_conditions { @{$_[0]->{failure_conditions}} = () }
 
 around send_email => sub {
   my ($orig, $self, $email, $env, @rest) = @_;
@@ -32,20 +47,22 @@ around send_email => sub {
   return $self->$orig($email, $env, @rest);
 };
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Transport::Failable - a wrapper to makes things fail predictably
 
 =head1 VERSION
 
-version 0.110005
+version 1.300010
 
 =head1 DESCRIPTION
 
@@ -68,10 +85,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
