@@ -1,8 +1,8 @@
 package Email::Sender::Transport::Maildir;
-BEGIN {
-  $Email::Sender::Transport::Maildir::VERSION = '0.101760';
+{
+  $Email::Sender::Transport::Maildir::VERSION = '1.300010';
 }
-use Moose;
+use Moo;
 with 'Email::Sender::Transport';
 # ABSTRACT: deliver mail to a maildir on disk
 
@@ -13,6 +13,44 @@ use File::Spec;
 
 use Sys::Hostname;
 
+use MooX::Types::MooseLike::Base qw(Bool);
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+{
+  package
+    Email::Sender::Success::MaildirSuccess;
+  use Moo;
+  use MooX::Types::MooseLike::Base qw(Str);
+  extends 'Email::Sender::Success';
+  has filename => (
+    is  => 'ro',
+    isa => Str,
+    required => 1,
+  );
+  no Moo;
+}
+
 
 my $HOSTNAME;
 BEGIN { ($HOSTNAME = hostname) =~ s/\..*//; }
@@ -21,6 +59,12 @@ sub _hostname { $HOSTNAME }
 my $MAILDIR_TIME    = 0;
 my $MAILDIR_COUNTER = 0;
 
+has [ qw(add_lines_header add_envelope_headers) ] => (
+  is  => 'ro',
+  isa => Bool,
+  default => sub { 1 },
+);
+
 has dir => (
   is  => 'ro',
   required => 1,
@@ -32,17 +76,21 @@ sub send_email {
 
   my $dupe = Email::Abstract->new(\do { $email->as_string });
 
-  $dupe->set_header('X-Email-Sender-From' => $env->{from});
-  $dupe->set_header('X-Email-Sender-To'   => @{ $env->{to} });
+  if ($self->add_envelope_headers) {
+    $dupe->set_header('X-Email-Sender-From' => $env->{from});
+    $dupe->set_header('X-Email-Sender-To'   => @{ $env->{to} });
+  }
 
   $self->_ensure_maildir_exists;
 
-  $self->_add_lines_header($dupe);
+  $self->_add_lines_header($dupe) if $self->add_lines_header;
   $self->_update_time;
 
-  $self->_deliver_email($dupe);
+  my $fn = $self->_deliver_email($dupe);
 
-  return $self->success;
+  return Email::Sender::Success::MaildirSuccess->new({
+    filename => $fn,
+  });
 }
 
 sub _ensure_maildir_exists {
@@ -60,8 +108,8 @@ sub _ensure_maildir_exists {
 sub _add_lines_header {
   my ($class, $email) = @_;
   return if $email->get_header("Lines");
-  my @lines = split /\n/, $email->get_body;
-  $email->set_header("Lines", scalar @lines);
+  my $lines = $email->get_body =~ tr/\n/\n/;
+  $email->set_header("Lines", $lines);
 }
 
 sub _update_time {
@@ -82,19 +130,25 @@ sub _deliver_email {
   # if (eval { $email->can('stream_to') }) {
   #  eval { $mail->stream_to($fh); 1 } or return;
   #} else {
-  print $tmp_fh $email->as_string
+  my $string = $email->as_string;
+  $string =~ s/\x0D\x0A/\x0A/g unless $^O eq 'MSWin32';
+  print $tmp_fh $string
     or Email::Sender::Failure->throw("could not write to $tmp_filename: $!");
 
   close $tmp_fh
     or Email::Sender::Failure->throw("error closing $tmp_filename: $!");
 
+  my $target_name = File::Spec->catfile($self->dir, 'new', $tmp_filename);
+
   my $ok = rename(
     File::Spec->catfile($self->dir, 'tmp', $tmp_filename),
-    File::Spec->catfile($self->dir, 'new', $tmp_filename),
+    $target_name,
   );
 
   Email::Sender::Failure->throw("could not move $tmp_filename from tmp to new")
     unless $ok;
+
+  return $target_name;
 }
 
 sub _delivery_fh {
@@ -107,6 +161,7 @@ sub _delivery_fh {
     $filename = join q{.}, $MAILDIR_TIME, $$, ++$MAILDIR_COUNTER, $hostname;
     my $filespec = File::Spec->catfile($self->dir, 'tmp', $filename);
     sysopen $fh, $filespec, O_CREAT|O_EXCL|O_WRONLY;
+    binmode $fh;
     Email::Sender::Failure->throw("cannot create $filespec for delivery: $!")
       unless $fh or $!{EEXIST};
   }
@@ -114,20 +169,22 @@ sub _delivery_fh {
   return ($filename, $fh);
 }
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Transport::Maildir - deliver mail to a maildir on disk
 
 =head1 VERSION
 
-version 0.101760
+version 1.300010
 
 =head1 DESCRIPTION
 
@@ -137,22 +194,27 @@ current directory (at the time of transport initialization).
 
 If the directory does not exist, it will be created.
 
-Three headers will be added:
+By default, three headers will be added:
 
  * X-Email-Sender-From - the envelope sender
  * X-Email-Sender-To   - the envelope recipients (one header per rcpt)
  * Lines               - the number of lines in the body
 
+These can be controlled with the C<add_lines_header> and
+C<add_envelope_headers> constructor arguments.
+
+The L<Email::Sender::Success> object returned on success has a C<filename>
+method that returns the filename to which the message was delivered.
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
