@@ -1,12 +1,18 @@
 package Email::Sender::Transport::SMTP::Persistent;
 {
-  $Email::Sender::Transport::SMTP::Persistent::VERSION = '0.110005';
+  $Email::Sender::Transport::SMTP::Persistent::VERSION = '1.300010';
 }
-use Moose;
+use Moo;
 extends 'Email::Sender::Transport::SMTP';
 # ABSTRACT: an SMTP client that stays online
 
 
+
+
+
+
+
+
 use Net::SMTP;
 
 has _cached_client => (
@@ -35,6 +41,14 @@ sub _smtp_client {
 sub _message_complete { }
 
 
+
+
+
+
+
+
+
+
 sub disconnect {
   my ($self) = @_;
   return unless $self->_cached_client;
@@ -42,20 +56,22 @@ sub disconnect {
   $self->_cached_client(undef);
 }
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Transport::SMTP::Persistent - an SMTP client that stays online
 
 =head1 VERSION
 
-version 0.110005
+version 1.300010
 
 =head1 DESCRIPTION
 
@@ -77,10 +93,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
