@@ -1,11 +1,20 @@
 package Email::Sender::Transport::Wrapper;
-BEGIN {
-  $Email::Sender::Transport::Wrapper::VERSION = '0.101760';
+{
+  $Email::Sender::Transport::Wrapper::VERSION = '1.300010';
 }
-use Moose;
+use Moo;
 with 'Email::Sender::Transport';
 # ABSTRACT: a mailer to wrap a mailer for mailing mail
 
+use Email::Sender::Util;
+
+
+
+
+
+
+
+
 
 has transport => (
   is   => 'ro',
@@ -19,20 +28,49 @@ sub send_email {
   $self->transport->send_email(@_);
 }
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
+sub is_simple {
+  return $_[0]->transport->is_simple;
+}
+
+sub allow_partial_success {
+  return $_[0]->transport->allow_partial_success;
+}
+
+sub BUILDARGS {
+  my $self = shift;
+  my $href = $self->SUPER::BUILDARGS(@_);
+
+  if (my $class = delete $href->{transport_class}) {
+    Carp::confess("given both a transport and transport_class")
+      if $href->{transport};
+
+    my %arg;
+    for my $key (map {; /^transport_arg_(.+)$/ ? "$1" : () } keys %$href) {
+      $arg{$key} = delete $href->{"transport_arg_$key"};
+    }
+
+    $href->{transport} = Email::Sender::Util->_easy_transport($class, \%arg);
+  }
+
+  return $href;
+}
+
+no Moo;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Transport::Wrapper - a mailer to wrap a mailer for mailing mail
 
 =head1 VERSION
 
-version 0.101760
+version 1.300010
 
 =head1 DESCRIPTION
 
@@ -46,10 +84,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
