@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Email::Sender::Util;
 {
-  $Email::Sender::Util::VERSION = '0.110005';
+  $Email::Sender::Util::VERSION = '1.300010';
 }
 # ABSTRACT: random stuff that makes Email::Sender go
 
@@ -11,6 +11,7 @@ use Email::Sender::Failure;
 use Email::Sender::Failure::Permanent;
 use Email::Sender::Failure::Temporary;
 use List::MoreUtils ();
+use Module::Runtime qw(require_module);
 
 # This code will be used by Email::Sender::Simple. -- rjbs, 2008-12-04
 sub _recipients_from_email {
@@ -55,18 +56,32 @@ sub _failure {
   });
 }
 
+sub _easy_transport {
+  my ($self, $transport_class, $arg) = @_;
+
+  if ($transport_class !~ tr/://) {
+    $transport_class = "Email::Sender::Transport::$transport_class";
+  }
+
+  require_module($transport_class);
+  return $transport_class->new($arg);
+}
+
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Util - random stuff that makes Email::Sender go
 
 =head1 VERSION
 
-version 0.110005
+version 1.300010
 
 =head1 AUTHOR
 
@@ -74,10 +89,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
